==> ver.B.b14.02.tar.gz: ver.B.b14.02/env/src/gbs/lib/mx/init_function.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"mx_format.h"


void
init_gmxConstant(XLISP_ENV * env0,XLISP_ENV * env1)
{
	set_env(env0,l_string(std_cm,"MI_DEF_TP"),get_integer(MI_DEF_TP,0));
	set_env(env0,l_string(std_cm,"MI_DEF_MD"),get_integer(MI_DEF_MD,0));
	set_env(env0,l_string(std_cm,"MI_DEF_BT"),get_integer(MI_DEF_BT,0));

	set_env(env0,l_string(std_cm,"MI_FETCH_1_TP"),get_integer(MI_FETCH_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_1_MD"),get_integer(MI_FETCH_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_1_BT"),get_integer(MI_FETCH_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_FETCH_2_TP"),get_integer(MI_FETCH_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_2_MD"),get_integer(MI_FETCH_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_2_BT"),get_integer(MI_FETCH_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_EDIT_1_TP"),get_integer(MI_EDIT_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_1_MD"),get_integer(MI_EDIT_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_1_BT"),get_integer(MI_EDIT_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_EDIT_2_TP"),get_integer(MI_EDIT_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_2_MD"),get_integer(MI_EDIT_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_2_BT"),get_integer(MI_EDIT_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_VISU_1_TP"),get_integer(MI_VISU_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_VISU_1_MD"),get_integer(MI_VISU_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_VISU_1_BT"),get_integer(MI_VISU_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_VISU_2_TP"),get_integer(MI_VISU_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_VISU_2_MD"),get_integer(MI_VISU_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_VISU_2_BT"),get_integer(MI_VISU_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_SAVE_TP"),get_integer(MI_SAVE_TP,0));
	set_env(env0,l_string(std_cm,"MI_SAVE_MD"),get_integer(MI_SAVE_MD,0));
	set_env(env0,l_string(std_cm,"MI_SAVE_BT"),get_integer(MI_SAVE_BT,0));
}

void
init_gmx_lib_function(XLISP_ENV * env0,XLISP_ENV * env1)
{

	
	init_gmxGetPoint(env0,env1);
	init_gmxCreate(env0,env1);
	init_gmxConstant(env0,env1);
	init_gmxClose(env0,env1);
	init_gmxPNMStatus(env0,env1);
	init_gmxImportPNM(env0,env1);
	init_gmxExportPNM(env0,env1);
	init_gmxScan(env0,env1);
	init_gmxStatus(env0,env1);
}

==> ver.B.b16.11.tar.gz: ver.B.b16.11/env/src/gbs/lib/mx/init_function.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"mx_format.h"
#include	"pg_vector.h"

void
init_gmxConstant(XLISP_ENV * env0,XLISP_ENV * env1)
{
	set_env(env0,l_string(std_cm,"MI_DEF_TP"),get_integer(MI_DEF_TP,0));
	set_env(env0,l_string(std_cm,"MI_DEF_MD"),get_integer(MI_DEF_MD,0));
	set_env(env0,l_string(std_cm,"MI_DEF_BT"),get_integer(MI_DEF_BT,0));

	set_env(env0,l_string(std_cm,"MI_FETCH_1_TP"),get_integer(MI_FETCH_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_1_MD"),get_integer(MI_FETCH_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_1_BT"),get_integer(MI_FETCH_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_FETCH_2_TP"),get_integer(MI_FETCH_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_2_MD"),get_integer(MI_FETCH_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_FETCH_2_BT"),get_integer(MI_FETCH_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_EDIT_1_TP"),get_integer(MI_EDIT_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_1_MD"),get_integer(MI_EDIT_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_1_BT"),get_integer(MI_EDIT_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_EDIT_2_TP"),get_integer(MI_EDIT_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_2_MD"),get_integer(MI_EDIT_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_EDIT_2_BT"),get_integer(MI_EDIT_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_VISU_1_TP"),get_integer(MI_VISU_1_TP,0));
	set_env(env0,l_string(std_cm,"MI_VISU_1_MD"),get_integer(MI_VISU_1_MD,0));
	set_env(env0,l_string(std_cm,"MI_VISU_1_BT"),get_integer(MI_VISU_1_BT,0));

	set_env(env0,l_string(std_cm,"MI_VISU_2_TP"),get_integer(MI_VISU_2_TP,0));
	set_env(env0,l_string(std_cm,"MI_VISU_2_MD"),get_integer(MI_VISU_2_MD,0));
	set_env(env0,l_string(std_cm,"MI_VISU_2_BT"),get_integer(MI_VISU_2_BT,0));

	set_env(env0,l_string(std_cm,"MI_SAVE_TP"),get_integer(MI_SAVE_TP,0));
	set_env(env0,l_string(std_cm,"MI_SAVE_MD"),get_integer(MI_SAVE_MD,0));
	set_env(env0,l_string(std_cm,"MI_SAVE_BT"),get_integer(MI_SAVE_BT,0));
}

void
init_gmx_lib_function(XLISP_ENV * env0,XLISP_ENV * env1)
{

	
	init_gmxGetPoint(env0,env1);
	init_gmxCreate(env0,env1);
	init_gmxConstant(env0,env1);
	init_gmxClose(env0,env1);
	init_gmxPNMStatus(env0,env1);
	init_gmxImportPNM(env0,env1);
	init_gmxExportPNM(env0,env1);
	init_gmxScan(env0,env1);
	init_gmxStatus(env0,env1);
	init_gmxCopy(env0,env1);


	init_mxPgPlot(env1);
	init_gmxPgPlotInsert(env0,env1);
	init_gmxPgPlotField(env0,env1);
	init_gmxPgDisplay(env0,env1);
}
